pub struct Bip321 { /* private fields */ }Expand description
A parsed Bitcoin BIP321 URI with optional parameters.
BIP321 extends BIP21 by allowing URIs without a bitcoin address in the path, as long as there is at least one payment instruction in the query parameters.
For example: bitcoin:?ark=ark1qq...&amount=0.00000222
Implementations
Sourceimpl Bip321
impl Bip321
Sourcepub fn lightning(&self) -> Option<Arc<Bolt11Invoice>>
Available on crate feature lightning only.
pub fn lightning(&self) -> Option<Arc<Bolt11Invoice>>
lightning only.Returns the lightning BOLT11 invoice as a string if present
Sourcepub fn payjoin_output_substitution(&self) -> bool
pub fn payjoin_output_substitution(&self) -> bool
Returns whether payjoin output substitution is allowed (defaults to true if absent)
Sourcepub fn silent_payment_address(&self) -> Option<String>
pub fn silent_payment_address(&self) -> Option<String>
Returns the silent payment address (BIP-352) if present