pub struct Bolt11Invoice { /* private fields */ }Available on crate feature
lightning only.Expand description
Represents a syntactically and semantically correct lightning BOLT11 invoice.
Implementations
Sourceimpl Bolt11Invoice
impl Bolt11Invoice
Sourcepub fn amount_milli_satoshis(&self) -> Option<u64>
pub fn amount_milli_satoshis(&self) -> Option<u64>
Returns the amount in millisatoshis if present, None if it’s an “any amount” invoice
Sourcepub fn payment_hash(&self) -> String
pub fn payment_hash(&self) -> String
Returns the payment hash as a hex string
Sourcepub fn invoice_description(&self) -> String
pub fn invoice_description(&self) -> String
Returns the invoice description as a string
Sourcepub fn payee_pub_key(&self) -> Option<String>
pub fn payee_pub_key(&self) -> Option<String>
Returns the payee’s public key if present as a hex string
Sourcepub fn expiry_time(&self) -> u64
pub fn expiry_time(&self) -> u64
Returns the expiry time in seconds (default is 3600 seconds / 1 hour if not specified)
Sourcepub fn min_final_cltv_expiry_delta(&self) -> u64
pub fn min_final_cltv_expiry_delta(&self) -> u64
Returns the minimum CLTV expiry delta
Sourcepub fn payment_secret(&self) -> String
pub fn payment_secret(&self) -> String
Returns the payment secret as a debug string