BoltzSession

Struct BoltzSession 

pub struct BoltzSession { /* private fields */ }
Available on crate feature lightning only.
A session to pay and receive lightning payments.

Lightning payments are done via LBTC swaps using Boltz.

See BoltzSessionBuilder for various options to configure the session.

Implementations

Source

impl BoltzSession

pub fn new(network: &Network, client: &AnyClient) -> Result<Self, LwkError>

Create the lightning session with default settings

This uses default timeout and generates a random mnemonic. For custom configuration, use BoltzSession::from_builder() instead.

pub fn from_builder(builder: BoltzSessionBuilder) -> Result<Self, LwkError>

Create the lightning session from a builder

pub fn prepare_pay( &self, lightning_payment: &LightningPayment, refund_address: &Address, webhook: Option<Arc<WebHook>>, ) -> Result<PreparePayResponse, LwkError>

Prepare to pay a bolt11 invoice

pub fn restore_prepare_pay( &self, data: &str, ) -> Result<PreparePayResponse, LwkError>

Restore a payment from its serialized data see PreparePayResponse::serialize

pub fn invoice( &self, amount: u64, description: Option<String>, claim_address: &Address, webhook: Option<Arc<WebHook>>, ) -> Result<InvoiceResponse, LwkError>

Create a new invoice for a given amount and a claim address to receive the payment

pub fn restore_invoice(&self, data: &str) -> Result<InvoiceResponse, LwkError>

Restore an invoice flow from its serialized data see InvoiceResponse::serialize

pub fn btc_to_lbtc( &self, amount: u64, refund_address: &BitcoinAddress, claim_address: &Address, webhook: Option<Arc<WebHook>>, ) -> Result<LockupResponse, LwkError>

Create an onchain swap to convert BTC to LBTC

pub fn lbtc_to_btc( &self, amount: u64, refund_address: &Address, claim_address: &BitcoinAddress, webhook: Option<Arc<WebHook>>, ) -> Result<LockupResponse, LwkError>

Create an onchain swap to convert LBTC to BTC

pub fn restore_lockup(&self, data: &str) -> Result<LockupResponse, LwkError>

Restore an onchain swap from its serialized data see LockupResponse::serialize

pub fn rescue_file(&self) -> Result<String, LwkError>

Generate a rescue file with lightning session mnemonic.

The rescue file is a JSON file that contains the swaps mnemonic. It can be used on the Boltz web app to bring non terminated swaps to completition.

pub fn swap_restore(&self) -> Result<SwapList, LwkError>

Returns a the list of all the swaps ever done with the session mnemonic.

The object returned can be converted to a json String with toString()

pub fn restorable_reverse_swaps( &self, swap_list: &SwapList, claim_address: &Address, ) -> Result<Vec<String>, LwkError>

Filter the swap list to only include restorable reverse swaps

pub fn restorable_submarine_swaps( &self, swap_list: &SwapList, refund_address: &Address, ) -> Result<Vec<String>, LwkError>

Filter the swap list to only include restorable submarine swaps

pub fn restorable_btc_to_lbtc_swaps( &self, swap_list: &SwapList, claim_address: &Address, refund_address: &BitcoinAddress, ) -> Result<Vec<String>, LwkError>

Filter the swap list to only include restorable BTC to LBTC swaps

pub fn restorable_lbtc_to_btc_swaps( &self, swap_list: &SwapList, claim_address: &BitcoinAddress, refund_address: &Address, ) -> Result<Vec<String>, LwkError>

Filter the swap list to only include restorable LBTC to BTC swaps

pub fn fetch_swaps_info(&self) -> Result<String, LwkError>

Fetch informations, such as min and max amounts, about the reverse and submarine pairs from the boltz api.

pub fn next_index_to_use(&self) -> u32

Get the next index to use for deriving keypairs

pub fn set_next_index_to_use(&self, next_index_to_use: u32)

Set the next index to use for deriving keypairs

This may be necessary to handle multiple sessions with the same mnemonic.