Signer

Struct Signer 

pub struct Signer { /* private fields */ }
A Software signer, wrapper over lwk_signer::SwSigner

Implementations

Source

impl Signer

pub fn amp0_signer_data(&self) -> Result<Amp0SignerData, LwkError>

AMP0 signer data for login

Source

impl Signer

pub fn new( mnemonic: &Mnemonic, network: &Network, ) -> Result<Arc<Self>, LwkError>

Construct a software signer

pub fn random(network: &Network) -> Result<Arc<Self>, LwkError>

Generate a new random software signer

pub fn sign(&self, pset: &Pset) -> Result<Arc<Pset>, LwkError>

Sign the given pset

Note from an API perspective it would be better to consume the pset parameter so it would be clear the signed PSET is the returned one, but it’s not possible with uniffi bindings

pub fn wpkh_slip77_descriptor(&self) -> Result<Arc<WolletDescriptor>, LwkError>

Return the witness public key hash, slip77 descriptor of this signer

pub fn singlesig_desc( &self, script_variant: Singlesig, blinding_variant: DescriptorBlindingKey, ) -> Result<Arc<WolletDescriptor>, LwkError>

Generate a singlesig descriptor with the given parameters

pub fn keyorigin_xpub(&self, bip: &Bip) -> Result<String, LwkError>

Return keyorigin and xpub, like “[73c5da0a/84h/1h/0h]tpub…”

pub fn fingerprint(&self) -> Result<String, LwkError>

Return the signer fingerprint

pub fn mnemonic(&self) -> Result<Arc<Mnemonic>, LwkError>

Get the mnemonic of the signer

pub fn derive_bip85_mnemonic( &self, index: u32, word_count: u32, ) -> Result<Arc<Mnemonic>, LwkError>

Derive a BIP85 mnemonic from this signer

Arguments
  • index - The index for the derived mnemonic (0-based)
  • word_count - The number of words in the derived mnemonic (12 or 24)
Returns
  • Ok(Mnemonic) - The derived BIP85 mnemonic
  • Err(LwkError) - If BIP85 derivation fails
Example
signer = Signer.new(mnemonic, network)
derived_mnemonic = signer.derive_bip85_mnemonic(0, 12)