pub struct SecretKey { /* private fields */ }Expand description
A secret key
Implementations
Sourceimpl SecretKey
impl SecretKey
Sourcepub fn from_bytes(bytes: &[u8]) -> Result<Arc<Self>, LwkError>
pub fn from_bytes(bytes: &[u8]) -> Result<Arc<Self>, LwkError>
Creates a SecretKey from a byte array
The bytes can be used to create a SecretKey with from_bytes()
Sourcepub fn bytes(&self) -> Vec<u8> ⓘ
pub fn bytes(&self) -> Vec<u8> ⓘ
Returns the bytes of the secret key, the bytes can be used to create a SecretKey with from_bytes()