pub struct Signer { /* private fields */ }Expand description
A Software signer, wrapper over lwk_signer::SwSigner
Implementations
Sourceimpl Signer
impl Signer
Sourcepub fn amp0_signer_data(&self) -> Result<Amp0SignerData, LwkError>
pub fn amp0_signer_data(&self) -> Result<Amp0SignerData, LwkError>
AMP0 signer data for login
Sourceimpl Signer
impl Signer
Sourcepub fn new(
mnemonic: &Mnemonic,
network: &Network,
) -> Result<Arc<Self>, LwkError>
pub fn new( mnemonic: &Mnemonic, network: &Network, ) -> Result<Arc<Self>, LwkError>
Construct a software signer
Sourcepub fn random(network: &Network) -> Result<Arc<Self>, LwkError>
pub fn random(network: &Network) -> Result<Arc<Self>, LwkError>
Generate a new random software signer
Sourcepub fn sign(&self, pset: &Pset) -> Result<Arc<Pset>, LwkError>
pub fn sign(&self, pset: &Pset) -> Result<Arc<Pset>, LwkError>
Sign the given pset
Note from an API perspective it would be better to consume the pset parameter so it would
be clear the signed PSET is the returned one, but it’s not possible with uniffi bindings
Sourcepub fn wpkh_slip77_descriptor(&self) -> Result<Arc<WolletDescriptor>, LwkError>
pub fn wpkh_slip77_descriptor(&self) -> Result<Arc<WolletDescriptor>, LwkError>
Return the witness public key hash, slip77 descriptor of this signer
Sourcepub fn singlesig_desc(
&self,
script_variant: Singlesig,
blinding_variant: DescriptorBlindingKey,
) -> Result<Arc<WolletDescriptor>, LwkError>
pub fn singlesig_desc( &self, script_variant: Singlesig, blinding_variant: DescriptorBlindingKey, ) -> Result<Arc<WolletDescriptor>, LwkError>
Generate a singlesig descriptor with the given parameters
Sourcepub fn keyorigin_xpub(&self, bip: &Bip) -> Result<String, LwkError>
pub fn keyorigin_xpub(&self, bip: &Bip) -> Result<String, LwkError>
Return keyorigin and xpub, like “[73c5da0a/84h/1h/0h]tpub…”
Sourcepub fn fingerprint(&self) -> Result<String, LwkError>
pub fn fingerprint(&self) -> Result<String, LwkError>
Return the signer fingerprint
Sourcepub fn derive_bip85_mnemonic(
&self,
index: u32,
word_count: u32,
) -> Result<Arc<Mnemonic>, LwkError>
pub fn derive_bip85_mnemonic( &self, index: u32, word_count: u32, ) -> Result<Arc<Mnemonic>, LwkError>
Derive a BIP85 mnemonic from this signer
Arguments
index- The index for the derived mnemonic (0-based)word_count- The number of words in the derived mnemonic (12 or 24)
Returns
Ok(Mnemonic)- The derived BIP85 mnemonicErr(LwkError)- If BIP85 derivation fails
Example
signer = Signer.new(mnemonic, network)
derived_mnemonic = signer.derive_bip85_mnemonic(0, 12)Trait Implementations
Sourceimpl<UT> LowerError<UT> for Signer
impl<UT> LowerError<UT> for Signer
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for Signer
impl<UT> LowerReturn<UT> for Signer
Sourcetype ReturnType = <Arc<Signer> as LowerReturn<UniFfiTag>>::ReturnType
type ReturnType = <Arc<Signer> as LowerReturn<UniFfiTag>>::ReturnType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(obj: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
Sourcefn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more